package nu.zoom.catonine;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.nio.charset.Charset;
import java.util.LinkedList;
import java.util.regex.Matcher;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * 
 */
public class IndexingTailer extends AbstractFileTailer {

    private LinkedList<Range> index = new LinkedList<Range>();
    private Reader reader;
    private final Log log = LogFactory.getLog(getClass());

    /**
     * @param file
     * @param charset
     * @param sleepTime
     */
    public IndexingTailer(File file, Charset charset, long sleepTime) {
        super(file, charset, sleepTime);
    }

    /*
     * (non-Javadoc)
     * 
     * @see nu.zoom.catonine.AbstractFileTailer#charsetChanged(java.nio.charset.Charset)
     */
    @Override
    protected void charsetChanged(Charset newCharset) {
        // TODO Auto-generated method stub
    }

    /*
     * (non-Javadoc)
     * 
     * @see nu.zoom.catonine.AbstractFileTailer#fileToTailChanged(java.io.File)
     */
    @Override
    protected synchronized void fileToTailChanged(File newfile)
            throws IOException {
        setupReader(newfile);
        reindex();
    }

    /*
     * (non-Javadoc)
     * 
     * @see nu.zoom.catonine.AbstractThreadedTailer#read()
     */
    @Override
    protected synchronized void read() throws IOException {
    }

    public synchronized int getNumberOfBlocks() {
        return index.size();
    }

    private synchronized void reindex() throws IOException {
        index = new LinkedList<Range>();

        int start = 0;
        int end = 0;
        Matcher blockMatcher = createBlockMatcher();
        StringBuilder builder = new StringBuilder();
        int ch = reader.read();

        while (ch != -1) {
            builder.append((char) ch);
            blockMatcher.reset(builder);
            if (blockMatcher.matches()) {
                start = end;
                end = start + (isBlockMatcherStarting() ? blockMatcher.start()
                        : blockMatcher.end());
                Range range = new Range(start, end);
                index.addLast(range);
                builder = new StringBuilder();
            }

            ch = reader.read();
        }

        reader.close();
    }

    private void setupReader(File newfile) throws FileNotFoundException {
        if (reader != null) {
            try {
                reader.close();
            } catch (IOException e) {
                log.error("Unable to close current reader");
            }
        }
        reader = new BufferedReader(
                new InputStreamReader(
                new FileInputStream(newfile), getCharset().newDecoder()));
    }

    /**
     * Holds a start and end value. Start is guarantees to be less than or equal
     * to end and non negative.
     * 
     */
    private static class Range {

        private long start;
        private long end;

        public Range(final long start, final long end) {
            super();
            if (start > end) {
                throw new IllegalArgumentException(
                        "Start may not be beyond end");
            }
            if (start < 0) {
                throw new IllegalArgumentException(
                        "Start may not be less than 0");
            }
            this.start = start;
            this.end = end;
        }

        public synchronized long getStart() {
            return start;
        }

        public synchronized long getEnd() {
            return end;
        }
    }

    @Override
    public synchronized void validateState() throws IllegalArgumentException, IllegalStateException {
        super.validateState();
        if (reader == null) {
            log.error("Reader is null");
        }
        throw new IllegalStateException("Reader is null");
    }

    @Override
    protected void setup() {
        try {
            setupReader(getFile());
        } catch (IOException ex) {
            log.error(ex);
            reader = null;
        }
    }
}
