/*
 * Copyright (C) 2006 Johan Maasing johan at zoom.nu Licensed under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package nu.zoom.catonine;

import java.io.Serializable;
import java.util.List;

/**
 * Listens to events from the tailer.
 * @author johan
 */
public interface TailerListener {

    /**
     * The tailer has discovered new lines.
     * @param lines The new lines the tailer has discovered in the tail source.
     */
    public void lines(List<LogEntry> lines);

    /**
     * The tailer is busy doing some work.
     */
    public void tailerWorking();

    /**
     * The tailer has stopped working and has become idle.
     */
    public void tailerIdle();

    /**
     * Inform listeners that the tailer has stopped following its file.
     * The tailer is now dormant and will need to be restarted.
     */
    public void tailerStopped();

    /**
     * A log entry that the tailer has extracted from the file it is following.
     */
    public class LogEntry implements Serializable {

        private final long position;
        private final String content;

        public LogEntry(final long position, final String content) {
            this.position = position;
            this.content = content;
        }

        public String getContent() {
            return content;
        }

        public long getPosition() {
            return position;
        }
    }
}
