/*
 *  Copyright 2010 johan.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package nu.zoom.catonine.desktop;

import java.io.File;
import java.util.Set;
import nu.zoom.swing.desktop.common.BackendException;
import nu.zoom.swing.desktop.preferences.InvalidDataTypeException;
import nu.zoom.swing.desktop.preferences.Preferences;

/**
 *
 * @author johan
 */
public class PreferencesUtil {

    private PreferencesUtil() {
    }
    static final String MANAGER_FILENAME_PREFS_KEY = "StyleRuleManager.file";
    static final String MANAGER_FILECHOOSER_PREFS_KEY = "StyleRuleManager.filechooser";
    private static final String FILE_CONFIGURATION_PREFS_PREFIX = "StyleRuleManager.file.conf.";
    private static final String OPENED_FILES_PREFS_KEY = "StyleRuleManager.openfiles";

    public static String getPreferredUUIDForFile(final Preferences preferences, final File file) throws InvalidDataTypeException, BackendException {
        if (file == null) {
            throw new NullPointerException("File may not be null");
        }
        return preferences.getString(PreferencesUtil.FILE_CONFIGURATION_PREFS_PREFIX + file.getName());
    }

    public static void setPreferredUUIDForFile(final Preferences preferences, final File file, final String uuid) throws InvalidDataTypeException, BackendException {
        preferences.setString(PreferencesUtil.FILE_CONFIGURATION_PREFS_PREFIX + file.getName(), uuid);
    }

    public static void rememeberOpenedFiles(final Preferences preferences, final Set<String> filenames) throws InvalidDataTypeException, BackendException {
        preferences.setStrings(OPENED_FILES_PREFS_KEY, (filenames.size() < 1) ? null : filenames);
    }

    public static Set<String> getOpenedFiles(final Preferences preferences) throws InvalidDataTypeException, BackendException {
        return preferences.getStrings(OPENED_FILES_PREFS_KEY);
    }
}
