/*
 * Copyright (C) 2006 Johan Maasing johan at zoom.nu Licensed under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law
 * or agreed to in writing, software distributed under the License is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package nu.zoom.catonine.swing;

import java.awt.EventQueue;
import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.util.List;
import javax.swing.Icon;

import javax.swing.JOptionPane;

import nu.zoom.catonine.AbstractThreadedTailer;
import nu.zoom.catonine.TailerListener;
import nu.zoom.catonine.ui.LocalizedResources;
import nu.zoom.catonine.ui.LocalizedResources.ResourceNotFoundException;
import nu.zoom.swing.action.AbstractTypedAction;

class TailControlAction extends AbstractTypedAction implements TailerListener {

    private static final long serialVersionUID = 1L;
    private AbstractThreadedTailer tailer;
    private final String startFollowText;
    private final String stopFollowText;
    private final Icon startFollowIcon;
    private final Icon stopFollowIcon;

    public TailControlAction(final AbstractThreadedTailer tailer, final LocalizedResources localizedResources) throws ResourceNotFoundException {
        this.tailer = tailer;
        startFollowText = localizedResources.getMessage("nu.zoom.catonine.tail.startfollow");
        startFollowIcon = localizedResources.getIcon("nu.zoom.catonine.tail.startfollow.icon");
        stopFollowText = localizedResources.getMessage("nu.zoom.catonine.tail.stopfollow");
        stopFollowIcon = localizedResources.getIcon("nu.zoom.catonine.tail.stopfollow.icon");
        setName(stopFollowText);
        setIcon(stopFollowIcon);
        setToolTip(localizedResources.getMessage("nu.zoom.catonine.tail.tt"));
        setMnemonicKey(KeyEvent.VK_F);
        setAcceleratorKey(KeyEvent.VK_F, InputEvent.SHIFT_DOWN_MASK);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        try {
            if (tailer.isTailing()) {
                tailer.stop();
            } else {
                tailer.start();
            }
        } catch (Exception e1) {
            JOptionPane.showMessageDialog(null, e1);
        }
    }

    @Override
    public void lines(List<LogEntry> lines) {
    }

    private void setActive() {
        setName(stopFollowText);
        setIcon(stopFollowIcon);
    }

    private void setInactive() {
        setName(startFollowText);
        setIcon(startFollowIcon);
    }

    @Override
    public void tailerWorking() {
    }

    @Override
    public void tailerIdle() {
        EventQueue.invokeLater(new Runnable() {

            @Override
            public void run() {
                setActive();
            }
        });
    }

    @Override
    public void tailerStopped() {
        EventQueue.invokeLater(new Runnable() {

            @Override
            public void run() {
                setInactive();
            }
        });
    }
}
