/*
 *  Copyright 2010 johan.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package nu.zoom.catonine.swing;

import java.util.ArrayList;
import java.util.List;
import javax.swing.JSeparator;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import nu.zoom.catonine.StyleRules;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *
 * @author johan
 */
public class TimestampDocument extends StyleRulesDocument {

    static final String TIMESTAMP_STYLE_NAME = "timestamp";
    private final Log log = LogFactory.getLog(getClass());
    private final ArrayList<Long> timestampPositions = new ArrayList<Long>();

    public TimestampDocument() {
        super();
    }

    public synchronized void addStampAfter(Long position) {
        if (!timestampPositions.contains(position)) {
            timestampPositions.add(position);
        }
    }

    public synchronized void addStampAfterLast() {
        addStampAfter(getLastBlockPosition());
    }

    public synchronized void removeAllStamps() {
        log.debug("Remove all stamps");
        timestampPositions.clear();
    }

    @Override
    protected void setConfiguration(StyleRules configuration) {
        super.setConfiguration(configuration);
        removeAllStamps();
    }

    @Override
    protected synchronized void append(List<LogEntry> blocks) {
        for (LogEntry block : blocks) {
            String style = getStyleName(block.getContent());
            if (style != null) {
                final String content = block.getContent();
                append(content, style);
            } else {
                // Style == null means that the line should be
                // supressed
            }
            if (shouldStampAfter(block)) {

                SimpleAttributeSet stampStyle = new SimpleAttributeSet(getStyle(DEFAULT_STYLE_NAME));
                StyleConstants.setComponent(stampStyle, new JSeparator(JSeparator.HORIZONTAL));

                append("\n", stampStyle);
            }
        }
    }

    private synchronized boolean shouldStampAfter(LogEntry entry) {
        for (Long stamp : timestampPositions) {
            if (stamp.equals(entry.getPosition())) {
                return true;
            }
        }
        return false;
    }

    public synchronized Long getLastBlockPosition() {
        if (fileContent != null) {
            LogEntry lastEntry = fileContent.get(fileContent.size() - 1);
            return new Long(lastEntry.getPosition());
        }
        return null;
    }
}
