/*
 *  Copyright 2010 johan.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package nu.zoom.catonine.ui;

import java.net.URL;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import org.ops4j.gaderian.Messages;

/**
 * Hide the platform to get resources. This is mainly to prepare for moving
 * from zoom-desktop to OSGI & Netbeans.
 * @author Johan Maasing
 */
public class LocalizedResources {

    private final Messages messages;

    public LocalizedResources(final Messages messages) {
        this.messages = messages;
    }

    public String getMessage(final String key) throws ResourceNotFoundException {
        final String value = messages.getMessage(key);
        if (value == null) {
            throw new ResourceNotFoundException("Unable to find a string for key: " + key);
        }
        return value;
    }

    public String format(final String key, final Object... args) throws ResourceNotFoundException {
        final String template = messages.format(key, args);
//        if (template == null) {
//            throw new ResourceNotFoundException("Unable to find string for key: " + key);
//        }
//        return String.format(template, args);
        return template ;
    }

    public Icon getIcon(final String key) throws ResourceNotFoundException {
        String resourceName = messages.getMessage(key);
        URL url = getClass().getResource(resourceName);
        ImageIcon icon = null;
        if (url != null) {
            icon = new ImageIcon(url);
            if (icon != null) {
                return icon;
            }
        }
        throw new ResourceNotFoundException("Unable to load Icon resource: " + key);
    }

    public static class ResourceNotFoundException extends Exception {

        public ResourceNotFoundException(Throwable cause) {
            super(cause);
        }

        public ResourceNotFoundException(String message, Throwable cause) {
            super(message, cause);
        }

        public ResourceNotFoundException(String message) {
            super(message);
        }
    }
}
